// Copyright 2018-present Network Optix, Inc. Licensed under MPL 2.0: www.mozilla.org/MPL/2.0/

#pragma once

#include <atomic>
#include <thread>
#include <memory>
#include <mutex>
#include <condition_variable>

#include <nx/sdk/uuid.h>
#include <nx/sdk/analytics/helpers/plugin.h>
#include <nx/sdk/analytics/helpers/engine.h>
#include <nx/sdk/analytics/i_uncompressed_video_frame.h>

namespace nx {
namespace vms_server_plugins {
namespace analytics {
namespace stub {
namespace diagnostic_events {

const std::string kThrowPluginDiagnosticEventsFromEngineSetting =
    "throwPluginDiagnosticEventsFromEngine";

class Engine: public nx::sdk::analytics::Engine
{
public:
    Engine(nx::sdk::analytics::Plugin* plugin);
    virtual ~Engine() override;

    nx::sdk::analytics::Plugin* const plugin() const { return m_plugin; }

protected:
    virtual std::string manifestString() const override;

    virtual nx::sdk::Result<const nx::sdk::ISettingsResponse*> settingsReceived() override;

protected:
    virtual void doObtainDeviceAgent(
        nx::sdk::Result<nx::sdk::analytics::IDeviceAgent*>* outResult,
        const nx::sdk::IDeviceInfo* deviceInfo) override;

private:
    void generatePluginDiagnosticEvents();

private:
    nx::sdk::analytics::Plugin* const m_plugin;

    mutable std::mutex m_pluginDiagnosticEventGenerationLoopMutex;
    mutable std::condition_variable m_pluginDiagnosticEventGenerationLoopCondition;
    std::unique_ptr<std::thread> m_pluginDiagnosticEventThread;
    std::atomic<bool> m_terminated{false};
    std::atomic<bool> m_needToThrowPluginDiagnosticEvents{false};
};

} // namespace diagnostic_events
} // namespace stub
} // namespace analytics
} // namespace vms_server_plugins
} // namespace nx
